@@ -273,7 +273,7 @@ class ShellTest(utils.TestCase):
         """
         expected = {'encryption': {'cipher': None, 'key_size': None,
                                    'provider': 'TestProvider',
-                                   'control_location': None}}
+                                   'control_location': 'front-end'}}
         self.run_command('encryption-type-create 2 TestProvider')
         self.assert_called('POST', '/types/2/encryption', body=expected)
         self.assert_called_anytime('GET', '/types/2')
@@ -347,7 +347,14 @@ class ShellTest(utils.TestCase):
         self.assert_called('PUT', '/os-services/disable',
                            {"binary": "cinder-volume", "host": "host"})
 
-    def test_service_disable(self):
+    def test_services_disable_with_reason(self):
+        cmd = 'service-disable host cinder-volume --reason no_reason'
+        self.run_command(cmd)
+        body = {'host': 'host', 'binary': 'cinder-volume',
+                'disabled_reason': 'no_reason'}
+        self.assert_called('PUT', '/os-services/disable-log-reason', body)
+
+    def test_service_enable(self):
         self.run_command('service-enable host cinder-volume')
         self.assert_called('PUT', '/os-services/enable',
                            {"binary": "cinder-volume", "host": "host"})
@@ -355,3 +362,11 @@ class ShellTest(utils.TestCase):
     def test_snapshot_delete(self):
         self.run_command('snapshot-delete 1234')
         self.assert_called('DELETE', '/snapshots/1234')
+
+    def test_quota_delete(self):
+        self.run_command('quota-delete 1234')
+        self.assert_called('DELETE', '/os-quota-sets/1234')
+
+    def test_snapshot_delete_multiple(self):
+        self.run_command('snapshot-delete 1234 5678')
+        self.assert_called('DELETE', '/snapshots/5678')
