@@ -27,27 +27,27 @@ class ServicesTest(utils.TestCase):
         svs = cs.services.list()
         cs.assert_called('GET', '/os-services')
         self.assertEqual(len(svs), 3)
-        [self.assertTrue(isinstance(s, services.Service)) for s in svs]
+        [self.assertIsInstance(s, services.Service) for s in svs]
 
     def test_list_services_with_hostname(self):
         svs = cs.services.list(host='host2')
         cs.assert_called('GET', '/os-services?host=host2')
         self.assertEqual(len(svs), 2)
-        [self.assertTrue(isinstance(s, services.Service)) for s in svs]
+        [self.assertIsInstance(s, services.Service) for s in svs]
         [self.assertEqual(s.host, 'host2') for s in svs]
 
     def test_list_services_with_binary(self):
         svs = cs.services.list(binary='cinder-volume')
         cs.assert_called('GET', '/os-services?binary=cinder-volume')
         self.assertEqual(len(svs), 2)
-        [self.assertTrue(isinstance(s, services.Service)) for s in svs]
+        [self.assertIsInstance(s, services.Service) for s in svs]
         [self.assertEqual(s.binary, 'cinder-volume') for s in svs]
 
     def test_list_services_with_host_binary(self):
         svs = cs.services.list('host2', 'cinder-volume')
         cs.assert_called('GET', '/os-services?host=host2&binary=cinder-volume')
         self.assertEqual(len(svs), 1)
-        [self.assertTrue(isinstance(s, services.Service)) for s in svs]
+        [self.assertIsInstance(s, services.Service) for s in svs]
         [self.assertEqual(s.host, 'host2') for s in svs]
         [self.assertEqual(s.binary, 'cinder-volume') for s in svs]
 
@@ -55,12 +55,21 @@ class ServicesTest(utils.TestCase):
         s = cs.services.enable('host1', 'cinder-volume')
         values = {"host": "host1", 'binary': 'cinder-volume'}
         cs.assert_called('PUT', '/os-services/enable', values)
-        self.assertTrue(isinstance(s, services.Service))
+        self.assertIsInstance(s, services.Service)
         self.assertEqual(s.status, 'enabled')
 
     def test_services_disable(self):
         s = cs.services.disable('host1', 'cinder-volume')
         values = {"host": "host1", 'binary': 'cinder-volume'}
         cs.assert_called('PUT', '/os-services/disable', values)
+        self.assertIsInstance(s, services.Service)
+        self.assertEqual(s.status, 'disabled')
+
+    def test_services_disable_log_reason(self):
+        s = cs.services.disable_log_reason(
+            'host1', 'cinder-volume', 'disable bad host')
+        values = {"host": "host1", 'binary': 'cinder-volume',
+                  "disabled_reason": "disable bad host"}
+        cs.assert_called('PUT', '/os-services/disable-log-reason', values)
         self.assertTrue(isinstance(s, services.Service))
         self.assertEqual(s.status, 'disabled')
