@@ -481,13 +481,21 @@ def do_snapshot_create(cs, args):
 
 
 @utils.arg('snapshot',
-           metavar='<snapshot>',
-           help='Name or ID of the snapshot to delete.')
+           metavar='<snapshot>', nargs='+',
+           help='Name or ID of the snapshot(s) to delete.')
 @utils.service_type('volume')
 def do_snapshot_delete(cs, args):
-    """Remove a snapshot."""
-    snapshot = _find_volume_snapshot(cs, args.snapshot)
-    snapshot.delete()
+    """Remove one or more snapshots."""
+    failure_count = 0
+    for snapshot in args.snapshot:
+        try:
+            _find_volume_snapshot(cs, snapshot).delete()
+        except Exception as e:
+            failure_count += 1
+            print("Delete for snapshot %s failed: %s" % (snapshot, e))
+    if failure_count == len(args.snapshot):
+        raise exceptions.CommandError("Unable to delete any of the specified "
+                                      "snapshots.")
 
 
 @utils.arg('snapshot', metavar='<snapshot>',
@@ -579,11 +587,12 @@ def do_type_create(cs, args):
 
 @utils.arg('id',
            metavar='<id>',
-           help="Unique ID of the volume type to delete")
+           help="Name or ID of the volume type to delete")
 @utils.service_type('volume')
 def do_type_delete(cs, args):
     """Delete a specific volume type."""
-    cs.volume_types.delete(args.id)
+    volume_type = _find_volume_type(cs, args.id)
+    cs.volume_types.delete(volume_type)
 
 
 @utils.arg('vtype',
@@ -615,15 +624,15 @@ def do_type_key(cs, args):
 def do_endpoints(cs, args):
     """Discover endpoints that get returned from the authenticate services."""
     catalog = cs.client.service_catalog.catalog
-    for e in catalog['access']['serviceCatalog']:
+    for e in catalog['serviceCatalog']:
         utils.print_dict(e['endpoints'][0], e['name'])
 
 
 def do_credentials(cs, args):
     """Show user credentials returned from auth."""
     catalog = cs.client.service_catalog.catalog
-    utils.print_dict(catalog['access']['user'], "User Credentials")
-    utils.print_dict(catalog['access']['token'], "Token")
+    utils.print_dict(catalog['user'], "User Credentials")
+    utils.print_dict(catalog['token'], "Token")
 
 
 _quota_resources = ['volumes', 'snapshots', 'gigabytes']
@@ -724,6 +733,15 @@ def do_quota_update(cs, args):
     _quota_update(cs.quotas, args.tenant, args)
 
 
+@utils.arg('tenant', metavar='<tenant_id>',
+           help='UUID of tenant to delete the quotas for.')
+@utils.service_type('volume')
+def do_quota_delete(cs, args):
+    """Delete the quotas for a tenant."""
+
+    cs.quotas.delete(args.tenant)
+
+
 @utils.arg('class_name', metavar='<class>',
            help='Name of quota class to list the quotas for.')
 @utils.service_type('volume')
@@ -985,6 +1003,10 @@ def do_service_list(cs, args):
     """List all the services. Filter by host & service binary."""
     result = cs.services.list(host=args.host, binary=args.binary)
     columns = ["Binary", "Host", "Zone", "Status", "State", "Updated_at"]
+    # NOTE(jay-lau-513): we check if the response has disabled_reason
+    # so as not to add the column when the extended ext is not enabled.
+    if result and hasattr(result[0], 'disabled_reason'):
+        columns.append("Disabled Reason")
     utils.print_list(result, columns)
 
 
@@ -1000,11 +1022,18 @@ def do_service_enable(cs, args):
 
 @utils.arg('host', metavar='<hostname>', help='Name of host.')
 @utils.arg('binary', metavar='<binary>', help='Service binary.')
+@utils.arg('--reason', metavar='<reason>',
+           help='Reason for disabling service.')
 @utils.service_type('volume')
 def do_service_disable(cs, args):
     """Disable the service."""
-    result = cs.services.disable(args.host, args.binary)
     columns = ["Host", "Binary", "Status"]
+    if args.reason:
+        columns.append('Disabled Reason')
+        result = cs.services.disable_log_reason(args.host, args.binary,
+                                                args.reason)
+    else:
+        result = cs.services.disable(args.host, args.binary)
     utils.print_list([result], columns)
 
 
@@ -1132,10 +1161,10 @@ def do_encryption_type_show(cs, args):
            choices=['front-end', 'back-end'],
            type=str,
            required=False,
-           default=None,
+           default='front-end',
            help="Notional service where encryption is performed (e.g., "
-           "front-end=Nova). Values: 'front-end', 'back-end' "
-           "(Optional, Default=None)")
+           "front-end=Nova) Values: 'front-end', 'back-end' "
+           "(Default='front-end')")
 @utils.service_type('volume')
 def do_encryption_type_create(cs, args):
     """Create a new encryption type for a volume type (Admin Only)."""
