@@ -14,7 +14,7 @@
 #    under the License.
 
 from cinderclient import client
-from cinderclient.v1 import availability_zones
+from cinderclient.v2 import availability_zones
 from cinderclient.v2 import limits
 from cinderclient.v2 import qos_specs
 from cinderclient.v2 import quota_classes
@@ -48,8 +48,8 @@ class Client(object):
                  endpoint_type='publicURL', extensions=None,
                  service_type='volumev2', service_name=None,
                  volume_service_name=None, retries=None,
-                 http_log_debug=False,
-                 cacert=None):
+                 http_log_debug=False, cacert=None,
+                 auth_system='keystone', auth_plugin=None):
         # FIXME(comstud): Rename the api_key argument above when we
         # know it's not being used as keyword argument
         password = api_key
@@ -95,7 +95,9 @@ class Client(object):
             volume_service_name=volume_service_name,
             retries=retries,
             http_log_debug=http_log_debug,
-            cacert=cacert)
+            cacert=cacert,
+            auth_system=auth_system,
+            auth_plugin=auth_plugin)
 
     def authenticate(self):
         """Authenticate against the server.
