@@ -531,13 +531,21 @@ def do_snapshot_create(cs, args):
 
 
 @utils.arg('snapshot',
-           metavar='<snapshot>',
-           help='Name or ID of the snapshot to delete.')
+           metavar='<snapshot>', nargs='+',
+           help='Name or ID of the snapshot(s) to delete.')
 @utils.service_type('volumev2')
 def do_snapshot_delete(cs, args):
-    """Remove a snapshot."""
-    snapshot = _find_volume_snapshot(cs, args.snapshot)
-    snapshot.delete()
+    """Remove one or more snapshots."""
+    failure_count = 0
+    for snapshot in args.snapshot:
+        try:
+            _find_volume_snapshot(cs, snapshot).delete()
+        except Exception as e:
+            failure_count += 1
+            print("Delete for snapshot %s failed: %s" % (snapshot, e))
+    if failure_count == len(args.snapshot):
+        raise exceptions.CommandError("Unable to delete any of the specified "
+                                      "snapshots.")
 
 
 @utils.arg('snapshot', metavar='<snapshot>',
@@ -637,11 +645,12 @@ def do_type_create(cs, args):
 
 @utils.arg('id',
            metavar='<id>',
-           help="Unique ID of the volume type to delete")
+           help="Name or ID of the volume type to delete")
 @utils.service_type('volumev2')
 def do_type_delete(cs, args):
     """Delete a specific volume type."""
-    cs.volume_types.delete(args.id)
+    volume_type = _find_volume_type(cs, args.id)
+    cs.volume_types.delete(volume_type)
 
 
 @utils.arg('vtype',
@@ -668,18 +677,20 @@ def do_type_key(cs, args):
         vtype.unset_keys(list(keypair))
 
 
+@utils.service_type('volumev2')
 def do_endpoints(cs, args):
     """Discover endpoints that get returned from the authenticate services."""
     catalog = cs.client.service_catalog.catalog
-    for e in catalog['access']['serviceCatalog']:
+    for e in catalog['serviceCatalog']:
         utils.print_dict(e['endpoints'][0], e['name'])
 
 
+@utils.service_type('volumev2')
 def do_credentials(cs, args):
     """Show user credentials returned from auth."""
     catalog = cs.client.service_catalog.catalog
-    utils.print_dict(catalog['access']['user'], "User Credentials")
-    utils.print_dict(catalog['access']['token'], "Token")
+    utils.print_dict(catalog['user'], "User Credentials")
+    utils.print_dict(catalog['token'], "Token")
 
 
 _quota_resources = ['volumes', 'snapshots', 'gigabytes']
@@ -783,6 +794,15 @@ def do_quota_update(cs, args):
     _quota_update(cs.quotas, args.tenant, args)
 
 
+@utils.arg('tenant', metavar='<tenant_id>',
+           help='UUID of tenant to delete the quotas for.')
+@utils.service_type('volume')
+def do_quota_delete(cs, args):
+    """Delete the quotas for a tenant."""
+
+    cs.quotas.delete(args.tenant)
+
+
 @utils.arg('class_name',
            metavar='<class>',
            help='Name of quota class to list the quotas for.')
@@ -1002,6 +1022,28 @@ def do_backup_restore(cs, args):
     cs.restores.restore(args.backup, volume_id)
 
 
+@utils.arg('backup', metavar='<backup>',
+           help='ID of the backup to export.')
+@utils.service_type('volumev2')
+def do_backup_export(cs, args):
+    """Export backup metadata record."""
+    info = cs.backups.export_record(args.backup)
+    utils.print_dict(info)
+
+
+@utils.arg('backup_service', metavar='<backup_service>',
+           help='Backup service to use for importing the backup.')
+@utils.arg('backup_url', metavar='<backup_url>',
+           help='Backup URL for importing the backup metadata.')
+@utils.service_type('volumev2')
+def do_backup_import(cs, args):
+    """Import backup metadata record."""
+    info = cs.backups.import_record(args.backup_service, args.backup_url)
+    info.pop('links', None)
+
+    utils.print_dict(info)
+
+
 @utils.arg('volume', metavar='<volume>',
            help='Name or ID of the volume to transfer.')
 @utils.arg('--name',
@@ -1093,6 +1135,10 @@ def do_service_list(cs, args):
     """List all the services. Filter by host & service binary."""
     result = cs.services.list(host=args.host, binary=args.binary)
     columns = ["Binary", "Host", "Zone", "Status", "State", "Updated_at"]
+    # NOTE(jay-lau-513): we check if the response has disabled_reason
+    # so as not to add the column when the extended ext is not enabled.
+    if result and hasattr(result[0], 'disabled_reason'):
+        columns.append("Disabled Reason")
     utils.print_list(result, columns)
 
 
@@ -1108,11 +1154,18 @@ def do_service_enable(cs, args):
 
 @utils.arg('host', metavar='<hostname>', help='Name of host.')
 @utils.arg('binary', metavar='<binary>', help='Service binary.')
+@utils.arg('--reason', metavar='<reason>',
+           help='Reason for disabling service.')
 @utils.service_type('volumev2')
 def do_service_disable(cs, args):
     """Disable the service."""
-    result = cs.services.disable(args.host, args.binary)
     columns = ["Host", "Binary", "Status"]
+    if args.reason:
+        columns.append('Disabled Reason')
+        result = cs.services.disable_log_reason(args.host, args.binary,
+                                                args.reason)
+    else:
+        result = cs.services.disable(args.host, args.binary)
     utils.print_list([result], columns)
 
 
@@ -1240,10 +1293,10 @@ def do_encryption_type_show(cs, args):
            choices=['front-end', 'back-end'],
            type=str,
            required=False,
-           default=None,
+           default='front-end',
            help="Notional service where encryption is performed (e.g., "
-           "front-end=Nova). Values: 'front-end', 'back-end' "
-           "(Optional, Default=None)")
+           "front-end=Nova) Values: 'front-end', 'back-end' "
+           "(Default='front-end')")
 @utils.service_type('volumev2')
 def do_encryption_type_create(cs, args):
     """Create a new encryption type for a volume type (Admin Only)."""
@@ -1373,6 +1426,7 @@ def do_qos_disassociate_all(cs, args):
            nargs='+',
            default=[],
            help='QoS specs to set/unset (only key is necessary on unset)')
+@utils.service_type('volumev2')
 def do_qos_key(cs, args):
     """Set or unset specifications for a qos spec."""
     keypair = _extract_metadata(args)
